@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
 //
 //   XML documenting files to (X)HTML conversion script 
-//   Last updated on November 3, 2014
+//   Last updated on February 17, 2016
 //
 //   This file is part of Logtalk <http://logtalk.org/>  
-//   Copyright 1998-2015 Paulo Moura <pmoura@logtalk.org>
+//   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
 //   
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -34,7 +34,7 @@ var format = "xhtml";
 var directory = WshShell.CurrentDirectory;
 
 var index_file = "index.html";
-var index_title = "Entity documentation index";
+var index_title = "Documentation index";
 
 var processor = "msxsl";
 // var processor = "xsltproc";
@@ -72,10 +72,14 @@ else {
 	WScript.Quit(1);
 }
 
-var html_xslt = logtalk_user + "\\xml\\lgthtml.xsl";
-var xhtml_xslt = logtalk_user + "\\xml\\lgtxhtml.xsl";
+var html_entity_xslt = logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk_entity_to_html.xsl";
+var xhtml_entity_xslt = logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk_entity_to_xhtml.xsl";
 
-var xslt;
+var html_index_xslt = logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk_index_to_html.xsl"
+var xhtml_index_xslt = logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk_index_to_xhtml.xsl"
+
+var entity_xslt;
+var index_xslt;
 
 var f_arg = "";
 var d_arg = "";
@@ -127,25 +131,36 @@ if (p_arg != "" && p_arg != "msxsl" && p_arg != "xsltproc" && p_arg != "xalan" &
 } else if (p_arg != "")
 	processor = p_arg;
 
-if (format == "xhtml")
-	xslt = xhtml_xslt;
-else
-	xslt = html_xslt;
+if (format == "xhtml") {
+	entity_xslt = xhtml_entity_xslt;
+	index_xslt = xhtml_index_xslt;
+} else {
+	entity_xslt = html_entity_xslt;
+	index_xslt = html_entity_xslt;
+}
 
-if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk.dtd")) {
-	FSObject.CopyFile(logtalk_home + "\\xml\\logtalk.dtd", WshShell.CurrentDirectory + "\\logtalk.dtd");
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_entity.dtd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_entity.dtd", WshShell.CurrentDirectory + "\\logtalk_entity.dtd");
+}
+
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_index.dtd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_index.dtd", WshShell.CurrentDirectory + "\\logtalk_index.dtd");
 }
 
 if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\custom.ent")) {
-	FSObject.CopyFile(logtalk_home + "\\xml\\custom.ent", WshShell.CurrentDirectory + "\\custom.ent");
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\custom.ent", WshShell.CurrentDirectory + "\\custom.ent");
 }
 
-if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk.xsd")) {
-	FSObject.CopyFile(logtalk_home + "\\xml\\logtalk.xsd", WshShell.CurrentDirectory + "\\logtalk.xsd");
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_entity.xsd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_entity.xsd", WshShell.CurrentDirectory + "\\logtalk_entity.xsd");
+}
+
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_index.xsd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_index.xsd", WshShell.CurrentDirectory + "\\logtalk_index.xsd");
 }
 
 if (!FSObject.FileExists(directory + "\\logtalk.css")) {
-	FSObject.CopyFile(logtalk_user + "\\xml\\logtalk.css", directory + "\\logtalk.css");
+	FSObject.CopyFile(logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk.css", directory + "\\logtalk.css");
 }
 
 WScript.Echo("");
@@ -155,9 +170,15 @@ var files = new Enumerator(FSObject.GetFolder(WshShell.CurrentDirectory).Files);
 
 for (files.moveFirst(); !files.atEnd(); files.moveNext()) {
 	var file = files.item().name;
+	var xslt;
 	if (FSObject.GetExtensionName(file) == "xml") {
 		WScript.Echo("  converting " + file);
 		var html_file = directory + "\\" + FSObject.GetBaseName(file) + ".html";
+		if (file == "directory_index.xml" || file == "entity_index.xml" || file == "predicate_index.xml") {
+			xslt = index_xslt;
+		} else {
+			xslt = entity_xslt;
+		}
 		switch (processor) {
 			case "msxsl" :
 				WshShell.Run("msxsl -o \"" + html_file + "\" \"" + file + "\" \"" + xslt + "\"", true);
@@ -200,7 +221,7 @@ function usage_help() {
 	WScript.Echo("  f - output file format (either xhtml or html; default is " + format + ")");
 	WScript.Echo("  d - output directory for the generated files (default is " + directory + ")");
 	WScript.Echo("  i - name of the index file (default is " + index_file + ")");
-	WScript.Echo("  t - title to be used on the index file (default is " + index_title + ")");
+	WScript.Echo("  t - title to be used in the index file (default is " + index_title + ")");
 	WScript.Echo("  p - XSLT processor (msxsl, xsltproc, xalan, or sabcmd; default is " + processor + ")");
 	WScript.Echo("");
 	WScript.Quit(1);
@@ -234,18 +255,24 @@ function create_index_file() {
 
 	var files = new Enumerator(FSObject.GetFolder(WshShell.CurrentDirectory).Files);
 
-	for (files.moveFirst(); !files.atEnd(); files.moveNext()) {
-		var file = files.item().name;
-		if (FSObject.GetExtensionName(file) == "xml") {
-			var html_file = FSObject.GetBaseName(file) + ".html";
-			WScript.Echo("  indexing " + html_file);
-			var index = FSObject.GetBaseName(file).lastIndexOf("_");
-			var pars = FSObject.GetBaseName(file).slice(index+1);
-			var entity = FSObject.GetBaseName(file).slice(0, index);
-			if (pars == 0)
-				f.WriteLine("    <li><a href=\"" + html_file + "\">" + entity + "</a></li>");
-			else
-				f.WriteLine("    <li><a href=\"" + html_file + "\">" + entity + "/" + pars + "</a></li>");
+	if (FSObject.FileExists(WshShell.CurrentDirectory + "\\directory_index.xml")) {
+		f.WriteLine("    <li><a href=\"directory_index.html\">Directory index</a></li>");
+		f.WriteLine("    <li><a href=\"entity_index.html\">Entity index</a></li>");
+		f.WriteLine("    <li><a href=\"predicate_index.html\">Predicate index</a></li>");
+	} else {
+		for (files.moveFirst(); !files.atEnd(); files.moveNext()) {
+			var file = files.item().name;
+			if (FSObject.GetExtensionName(file) == "xml") {
+				var html_file = FSObject.GetBaseName(file) + ".html";
+				WScript.Echo("  indexing " + html_file);
+				var index = FSObject.GetBaseName(file).lastIndexOf("_");
+				var pars = FSObject.GetBaseName(file).slice(index+1);
+				var entity = FSObject.GetBaseName(file).slice(0, index);
+				if (pars == 0)
+					f.WriteLine("    <li><a href=\"" + html_file + "\">" + entity + "</a></li>");
+				else
+					f.WriteLine("    <li><a href=\"" + html_file + "\">" + entity + "/" + pars + "</a></li>");
+			}
 		}
 	}
 
