@@ -3,10 +3,10 @@
 #############################################################################
 ## 
 ##   XML documenting files to Mardown text files conversion script 
-##   Last updated on November 3, 2014
+##   Last updated on February 19, 2016
 ## 
 ##   This file is part of Logtalk <http://logtalk.org/>  
-##   Copyright 1998-2015 Paulo Moura <pmoura@logtalk.org>
+##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -79,7 +79,8 @@ elif ! [ -d "$LOGTALKUSER" ]; then
 fi
 echo
 
-xslt="$LOGTALKUSER/tools/lgtdoc/xml/lgtmd.xsl"
+entity_xslt="$LOGTALKUSER/tools/lgtdoc/xml/logtalk_entity_to_md.xsl"
+index_xslt="$LOGTALKUSER/tools/lgtdoc/xml/logtalk_index_to_md.xsl"
 
 processor=xsltproc
 # processor=xalan
@@ -87,6 +88,9 @@ processor=xsltproc
 
 directory="."
 
+index_file=index.md
+index_title="Documentation index"
+
 usage_help()
 {
 	echo 
@@ -94,21 +98,56 @@ usage_help()
 	echo "current directory to Markdown text files"
 	echo
 	echo "Usage:"
-	echo "  `basename $0` [-d directory] [-p processor]"
+	echo "  `basename $0` [-d directory] [-i index] [-t title] [-p processor]"
 	echo "  `basename $0` -h"
 	echo
 	echo "Optional arguments:"
 	echo "  -d output directory for the text files (default is $directory)"
+	echo "  -i name of the index file (default is $index_file)"
+	echo "  -t title to be used in the index file (default is $index_title)"
 	echo "  -p XSLT processor (xsltproc, xalan, or sabcmd; default is $processor)"
 	echo "  -h help"
 	echo
 	exit 1
 }
 
-while getopts "d:p:h" Option
+create_index_file()
+{
+	echo "" > "$index_file"
+
+	echo "# "$index_title >> "$index_file"
+	echo "" >> "$index_file"
+
+	if [ -e "./directory_index.xml" ] ; then
+		echo "* [Directory index](directory_index.md)" >> "$index_file"
+		echo "* [Entity index](entity_index.md)" >> "$index_file"
+		echo "* [Predicate index](predicate_index.md)" >> "$index_file"
+	else
+		for file in `grep -l "<logtalk_entity" *.xml`; do
+			name="`expr "$file" : '\(.*\)\.[^./]*$' \| "$file"`"
+			entity=${name%_*}
+			pars=${name##*_}
+			echo "  indexing $name.html"
+			if [ $pars -gt 0 ]
+			then
+				echo "* ["$entity"/"$pars"]("$name".md)" >> "$index_file"
+			else
+				echo "* ["$entity"]("$name".md)" >> "$index_file"
+			fi
+		done
+	fi
+
+	date="`eval date`"
+	echo "" >> "$index_file"
+	echo "Generated on "$date >> "$index_file"
+}
+
+while getopts "d:i:t:p:h" Option
 do
 	case $Option in
 		d) d_arg="$OPTARG";;
+		i) i_arg="$OPTARG";;
+		t) t_arg="$OPTARG";;
 		p) p_arg="$OPTARG";;
 		h) usage_help;;
 		*) usage_help;;
@@ -123,6 +162,14 @@ elif [ "$d_arg" != "" ] ; then
 	directory=$d_arg
 fi
 
+if [ "$i_arg" != "" ] ; then
+	index_file=$i_arg
+fi
+
+if [ "$t_arg" != "" ] ; then
+	index_title=$t_arg
+fi
+
 if [ "$p_arg" != "" ] && [ "$p_arg" != "fop" ] && [ "$p_arg" != "xep" ] && [ "$p_arg" != "xinc" ] ; then
 	echo "Error! Unsupported XSL-FO processor: $p_arg"
 	usage_help
@@ -131,32 +178,54 @@ elif [ "$p_arg" != "" ] ; then
 	processor=$p_arg
 fi
 
-if ! [ -e "./logtalk.dtd" ] ; then
-	cp "$LOGTALKHOME"/tools/lgtdoc/xml/logtalk.dtd .
+if ! [ -e "./logtalk_entity.dtd" ] ; then
+	cp "$LOGTALKHOME"/tools/lgtdoc/xml/logtalk_entity.dtd .
+fi
+
+if ! [ -e "./logtalk_index.dtd" ] ; then
+	cp "$LOGTALKHOME"/tools/lgtdoc/xml/logtalk_index.dtd .
 fi
 
 if ! [ -e "./custom.ent" ] ; then
 	cp "$LOGTALKUSER"/tools/lgtdoc/xml/custom.ent .
 fi
 
-if ! [ -e "./logtalk.xsd" ] ; then
-	cp "$LOGTALKHOME"/tools/lgtdoc/xml/logtalk.xsd .
+if ! [ -e "./logtalk_entity.xsd" ] ; then
+	cp "$LOGTALKHOME"/tools/lgtdoc/xml/logtalk_entity.xsd .
+fi
+
+if ! [ -e "./logtalk_index.xsd" ] ; then
+	cp "$LOGTALKHOME"/tools/lgtdoc/xml/logtalk_index.xsd .
 fi
 
 if [ `(grep -l "<logtalk" *.xml | wc -l) 2> /dev/null` -gt 0 ] ; then
 	echo
 	echo "converting XML files to Markdown text files..."
-	for file in `grep -l "<logtalk" *.xml`; do
+	for file in `grep -l "<logtalk_entity" *.xml`; do
 		echo "  converting $file"
 		name="`expr "$file" : '\(.*\)\.[^./]*$' \| "$file"`"
 		case "$processor" in
-			xsltproc)	eval xsltproc -o \"$directory\"/\"$name.md\" \"$xslt\" \"$file\";;
-			xalan)		eval xalan -o \"$directory\"/\"$name.md\" \"$file\" \"$xslt\";;
-			sabcmd)		eval sabcmd \"$xslt\" \"$file\" \"$directory\"/\"$name.md\";;
+			xsltproc)	eval xsltproc -o \"$directory\"/\"$name.md\" \"$entity_xslt\" \"$file\";;
+			xalan)		eval xalan -o \"$directory\"/\"$name.md\" \"$file\" \"$entity_xslt\";;
+			sabcmd)		eval sabcmd \"$entity_xslt\" \"$file\" \"$directory\"/\"$name.md\";;
+		esac
+	done
+	for file in `grep -l "<logtalk_index" *.xml`; do
+		echo "  converting $file"
+		name="`expr "$file" : '\(.*\)\.[^./]*$' \| "$file"`"
+		case "$processor" in
+			xsltproc)	eval xsltproc -o \"$directory\"/\"$name.md\" \"$index_xslt\" \"$file\";;
+			xalan)		eval xalan -o \"$directory\"/\"$name.md\" \"$file\" \"$index_xslt\";;
+			sabcmd)		eval sabcmd \"$index_xslt\" \"$file\" \"$directory\"/\"$name.md\";;
 		esac
 	done
 	echo "conversion done"
 	echo
+	index_file="$directory/$index_file"
+	echo "generating $index_file file..."
+	create_index_file
+	echo "index $index_file generated"
+	echo
 else
 	echo
 	echo "No XML files exist in the current directory!"
@@ -164,8 +233,10 @@ else
 fi
 
 if [ "$PWD" != "$LOGTALKHOME"/xml ] ; then
-	rm -f ./logtalk.dtd
-	rm -f ./logtalk.xsd
+	rm -f ./logtalk_entity.dtd
+	rm -f ./logtalk_index.dtd
+	rm -f ./logtalk_entity.xsd
+	rm -f ./logtalk_index.xsd
 	rm -f ./custom.ent
 fi
 
